@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Component.pm 6458 2007-04-11T03:33:18.491463Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Component.pm 4037 2007-10-25T14:20:48.994833Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -6,21 +6,7 @@
 package Gungho::Component;
 use strict;
 use warnings;
-use base qw(Gungho::Base);
-
-sub inject_base
-{
-    my $class = shift;
-    my $c     = shift;
-
-    my $pkg = ref($c);
-    {
-        no strict 'refs';
-        push @{ "${pkg}::ISA" }, $class;
-    }
-
-    $c->features->{ $class->feature_name }++;
-}
+use base qw(Gungho::Base::Class);
 
 sub feature_name
 {
@@ -56,6 +42,9 @@ from plugins in that it adds directly to Gungho's internals via subclassing.
 Plugins are called from various hooks, but components can directly interfere
 and/or add functionality to Gungho.
 
+To add a new component, just create a Gungho::Component subclass, and add
+it in your config. Gungho will ensure that it is loaded and setup.
+
 =head1 METHODS
 
 =head2 inject_base($c)
