@@ -1,10 +1,11 @@
-# $Id: /mirror/gungho/lib/Gungho/Handler/Null.pm 6417 2007-04-07T10:46:29.321551Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Handler/Null.pm 3234 2007-10-13T15:12:58.068532Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
 
 package Gungho::Handler::Null;
 use strict;
+use warnings;
 use base qw(Gungho::Handler);
 
 sub handle_response
@@ -14,8 +15,7 @@ sub handle_response
     my $req  = shift;
     my $res  = shift;
 
-    $c->log->info($req->uri . " responded with code " . $res->code)
-        if $c->log->is_info;
+    $c->log->info($req->uri . " responded with code " . $res->code);
     $self->next::method($c, $res);
 }
 
